# Examples that produce figures presented in Haselsteiner's doctoral thesis

The docstrings in the first lines of the Python scripts describe at which page the resulting figures are presented.

Haselsteiner, A. F. (2022). Offshore structures under extreme loads: A methodology to determine design loads [University of Bremen]. https://doi.org/10.26092/elib/1615
